LazyLock

Struct LazyLock 

pub struct LazyLock<T, F = fn() -> T, R = Spin> { /* private fields */ }
A value which is initialized on the first access.

This type is a thread-safe LazyLock, and can be used in statics.

Examples

use std::collections::HashMap;
use spin::LazyLock;

static HASHMAP: LazyLock<HashMap<i32, String>> = LazyLock::new(|| {
    println!("initializing");
    let mut m = HashMap::new();
    m.insert(13, "Spica".to_string());
    m.insert(74, "Hoyten".to_string());
    m
});

fn main() {
    println!("ready");
    std::thread::spawn(|| {
        println!("{:?}", HASHMAP.get(&13));
    }).join().unwrap();
    println!("{:?}", HASHMAP.get(&74));

    // Prints:
    //   ready
    //   initializing
    //   Some("Spica")
    //   Some("Hoyten")
}

Implementations

Source

impl<T, F, R> LazyLock<T, F, R>

pub const fn new(f: F) -> Self

Creates a new lazy value with the given initializing function.

pub fn as_mut_ptr(&self) -> *mut T

Retrieves a mutable pointer to the inner data.

This is especially useful when interfacing with low level code or FFI where the caller explicitly knows that it has exclusive access to the inner data. Note that reading from this pointer is UB until initialized or directly written to.

Source

impl<T, F: FnOnce() -> T, R: RelaxStrategy> LazyLock<T, F, R>

pub fn force(this: &Self) -> &T

Forces the evaluation of this lazy value and returns a reference to result. This is equivalent to the Deref impl, but is explicit.

Examples
use spin::LazyLock;

let lazy = LazyLock::new(|| 92);

assert_eq!(LazyLock::force(&lazy), &92);
assert_eq!(&*lazy, &92);